LinkValue class final
Represents a registry symbolic link value (REG_LINK).
- Inheritance
-
- Object
- RegistryValue
- LinkValue
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → RegistryValueType
-
The registry value type.
finalinherited
- value → String
-
The symbolic link target path.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override