RegistryKeyInfo class
Describes metadata about a registry key and its associated attributes.
Constructors
- RegistryKeyInfo({required String className, required int subKeyCount, required int subKeyNameMaxLength, required int subKeyClassNameMaxLength, required int valuesCount, required int valueNameMaxLength, required int valueDataMaxSizeInBytes, required int securityDescriptorLength, required DateTime? lastWriteTime})
-
Constructs a RegistryKeyInfo instance with detailed information about
the specified registry key attributes.
const
Properties
- className → String
-
The class name associated with the registry key.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastWriteTime → DateTime?
-
The date and time of the last modification to this registry key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityDescriptorLength → int
-
The size, in bytes, of the security descriptor associated with this key.
final
- subKeyClassNameMaxLength → int
-
The maximum length, in characters, of the subkey class names.
final
- subKeyCount → int
-
The number of subkeys contained within this registry key.
final
- subKeyNameMaxLength → int
-
The maximum length, in characters, of the subkey names.
final
- valueDataMaxSizeInBytes → int
-
The maximum size, in bytes, of the value data entries under this key.
final
- valueNameMaxLength → int
-
The maximum length, in characters, of the value names.
final
- valuesCount → int
-
The number of values directly associated with this registry key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited