StringValue class final
Represents a null-terminated UTF-16 string registry value (REG_SZ).
- Inheritance
-
- Object
- RegistryValue
- StringValue
Constructors
- StringValue(String value)
-
Creates a string registry value from
value.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → RegistryValueType
-
The registry value type.
finalinherited
- value → String
-
The string contents.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override